@@ -19,13 +19,13 @@ import logging
 import os
 from mkdocs.plugins import BasePlugin
 from mkdocs.theme import Theme
-from mkdocs.utils import warning_filter
 from mkdocs.contrib.search import SearchPlugin
+from material.plugins.search.plugin import SearchPlugin as MaterialSearchPlugin
 from mkdocs_monorepo_plugin.plugin import MonorepoPlugin
 from pymdownx.emoji import to_svg
+from pymdownx.extra import extra_extensions
 
 log = logging.getLogger(__name__)
-log.addFilter(warning_filter)
 
 TECHDOCS_DEFAULT_THEME = "material"
 
@@ -70,15 +70,21 @@ class TechDocsCore(BasePlugin):
         config["theme"]["features"].append("navigation.footer")
         config["theme"]["features"].append("content.action.edit")
 
-        config["theme"]["palette"] = ""
+        config["theme"]["palette"] = {}
 
         config["theme"].static_templates.update({"techdocs_metadata.json"})
         config["theme"].dirs.append(self.tmp_dir_techdocs_theme.name)
 
         # Plugins
+        use_material_search = config["plugins"]["techdocs-core"].config.get(
+            "use_material_search", False
+        )
         del config["plugins"]["techdocs-core"]
 
-        search_plugin = SearchPlugin()
+        if use_material_search:
+            search_plugin = MaterialSearchPlugin()
+        else:
+            search_plugin = SearchPlugin()
         search_plugin.load_config({})
 
         monorepo_plugin = MonorepoPlugin()
@@ -109,7 +115,6 @@ class TechDocsCore(BasePlugin):
         config["markdown_extensions"].append("pymdownx.mark")
         config["markdown_extensions"].append("pymdownx.smartsymbols")
         config["markdown_extensions"].append("pymdownx.snippets")
-        config["markdown_extensions"].append("pymdownx.superfences")
         config["markdown_extensions"].append("pymdownx.highlight")
         config["mdx_configs"]["pymdownx.highlight"] = {
             "linenums": True,
@@ -129,6 +134,17 @@ class TechDocsCore(BasePlugin):
         }
         config["markdown_extensions"].append("pymdownx.tilde")
 
+        # merge individual extension configs under the pymdownx.extra extension namespace if individual extension is supplied by pymdownx.extra
+        # https://facelessuser.github.io/pymdown-extensions/extensions/extra/
+        if "pymdownx.extra" not in config["mdx_configs"]:
+            config["mdx_configs"]["pymdownx.extra"] = {}
+        for extension in extra_extensions:
+            if extension in config["mdx_configs"]:
+                config["mdx_configs"]["pymdownx.extra"][extension] = config[
+                    "mdx_configs"
+                ][extension]
+                del config["mdx_configs"][extension]
+
         config["markdown_extensions"].append("markdown_inline_graphviz")
         config["markdown_extensions"].append("plantuml_markdown")
         config["markdown_extensions"].append("mdx_truly_sane_lists")
